@@ -13,7 +13,8 @@ from inspect import isfunction
 
 import logging
 import traceback
-
+import sys
+import os
 
 __all__ = (
     'Action',
@@ -198,6 +199,26 @@ class Env(object):
     def __repr__(self):
         return 'Env(%s)' % get_node_path(self._node)
 
+    @classmethod
+    def default_from_node(cls, node):
+        """
+        Create a default environment for this node to run.
+
+        It will be attached to stdin/stdout and commands will be logged to
+        stdout. The is the most obvious default.
+        """
+        from deployer.pseudo_terminal import Pty
+        from deployer.loggers import LoggerInterface
+        from deployer.loggers.default import DefaultLogger
+
+        pty = Pty(stdin=sys.stdin, stdout=sys.stdout, interactive=False,
+                term_var=os.environ.get('TERM', ''))
+
+        logger_interface = LoggerInterface()
+        logger_interface.attach(DefaultLogger())
+
+        return cls(node, pty=pty, logger=logger_interface, is_sandbox=False)
+
     def __wrap_action(self, action, auto_evaluate=True):
         """
         Wrap the action in an EnvAction object when it's called from the Env.
@@ -552,7 +573,7 @@ class ParallelNodeBase(NodeBase):
             Hosts = hosts
 
             @_internal
-            def __init__(self, parent):
+            def __init__(self, parent=None):
                 Node.__init__(self, parent)
                 if len(self.hosts.filter('host')) != 1:
                     raise Exception('Invalid initialisation of ParallelNode .JustOne. %i hosts given to %r.' %
